==> ordering-core-0.1.6.tgz: package/lib/esm/wsListener.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as StompJs from '@stomp/stompjs';
import { replaceProtocolInUrl } from './tools';
if (typeof TextEncoder !== 'function') {
    const TextEncodingPolyfill = require('text-encoding');
    global.TextEncoder = TextEncodingPolyfill.TextEncoder;
    global.TextDecoder = TextEncodingPolyfill.TextDecoder;
}
/**
 * Create Stomp on websocket connection to Ordering Stack listening for new orders to process by handlers/callback (onMessageAsync)
 *
 * @param {*} tenant
 * @param {*} venue
 * @param {*} accessTokenProviderCallbackAsync function called before connecting to STOMP server. Should return access token.
 * @param {*} onConnectedAsync async function (accessToken) {....}
 * @param {*} onDisconnectAsync
 * @param {*} onMessageAsync async function (message, accessToken) {....}
 */
export function connectWebSockets(params) {
    return __awaiter(this, void 0, void 0, function* () {
        let client;
        const baseURL = replaceProtocolInUrl(params.baseURL, 'wss://') + '/websocket';
        let userUUID = '';
        const stompConfig = {
            brokerURL: baseURL,
            debug: function (a) {
                console.log('DEBUG: ' + a);
            },
            reconnectDelay: 20000,
            heartbeatIncoming: 4000,
            heartbeatOutgoing: 4000,
            beforeConnect: function () {
                return __awaiter(this, void 0, void 0, function* () {
                    console.log('--- beforeConnect --- ');
                    const { token, UUID } = yield params.authDataProvider(baseURL, params.refreshTokenHandler, false);
                    if (!token) {
                        console.error('Access token provider error - deactivating socket');
                        client.deactivate();
                        if (params.onAuthFailure)
                            params.onAuthFailure();
                    }
                    stompConfig.connectHeaders = { login: token /*passcode: ''*/ };
                    userUUID = UUID;
                });
            },
            onConnect: function () {
                return __awaiter(this, void 0, void 0, function* () {
                    if (!stompConfig.connectHeaders)
                        return;
                    const accessToken = stompConfig.connectHeaders.login;
                    yield params.onConnectedAsync(accessToken);
                    console.log('Websocket connected.');
                    if (params.onKDSMessageAsync) {
                        var subscription = client.subscribe(`/kds/${params.tenant}/${params.venue}`, function (data) {
                            return __awaiter(this, void 0, void 0, function* () {
                                var message = JSON.parse(data.body);
                                yield params.onKDSMessageAsync(message);
                            });
                        });
                    }
                    if (params.onOrdersUpdateAsync) {
                        var subscriptionForOrdersUpdate = client.subscribe(`/order-changes/${params.tenant}/${userUUID}`, function (data) {
                            return __awaiter(this, void 0, void 0, function* () {
                                var message = JSON.parse(data.body);
                                yield params.onOrdersUpdateAsync(message);
                            });
                        });
                    }
                    if (params.onNotificationAsync) {
                        var subscriptionForNotifications = client.subscribe(`/notifications/${params.tenant}/${userUUID}`, function (data) {
                            return __awaiter(this, void 0, void 0, function* () {
                                var message = JSON.parse(data.body);
                                yield params.onNotificationAsync(message);
                            });
                        });
                    }
                });
            },
            onDisconnect: function () {
                return __awaiter(this, void 0, void 0, function* () {
                    yield params.onDisconnectAsync();
                    console.log('Websocket disconnected.');
                });
            },
            onStompError: function (frame) {
                return __awaiter(this, void 0, void 0, function* () {
                    // Will be invoked in case of error encountered at Broker
                    // Bad login/passcode typically will cause an error
                    // Complaint brokers will set `message` header with a brief message. Body may contain details.
                    // Compliant brokers will terminate the connection after any error
                    console.error('Broker reported error: ' + frame.headers['message']);
                    console.error('Additional details: ' + frame.body);
                    yield client.deactivate();
                    client = createNewClient(stompConfig);
                    client.activate();
                });
            },
            onWebSocketClose: function () {
                console.log('Websocket closed.');
            },
            onWebSocketError: function () {
                console.log('Websocket error.');
            },
            onUnhandledMessage: function () { },
            logRawCommunication: true,
            discardWebsocketOnCommFailure: true,
        };
        try {
            const { token, UUID } = yield params.authDataProvider(params.baseURL, params.refreshTokenHandler, false);
            stompConfig.connectHeaders = { login: token /*passcode: ''*/ };
            client = createNewClient(stompConfig);
            client.activate();
        }
        catch (err) {
            console.error(err);
        }
    });
}
function createNewClient(stompConfig) {
    const _client = new StompJs.Client(stompConfig);
    if (typeof WebSocket !== 'function') {
        // Fallback code
        _client.webSocketFactory = () => {
            const WebSocket = require('ws');
            global.WebSocket = WebSocket;
            console.log('create ws with ' + stompConfig.brokerURL);
            const ws = new WebSocket(stompConfig.brokerURL);
            return ws;
        };
    }
    return _client;
}

==> ordering-core-0.1.9.tgz: package/lib/esm/wsListener.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as StompJs from '@stomp/stompjs';
import { replaceProtocolInUrl } from './tools';
if (typeof TextEncoder !== 'function') {
    const TextEncodingPolyfill = require('text-encoding');
    global.TextEncoder = TextEncodingPolyfill.TextEncoder;
    global.TextDecoder = TextEncodingPolyfill.TextDecoder;
}
/**
 * Create Stomp on websocket connection to Ordering Stack listening for new orders to process by handlers/callback (onMessageAsync)
 *
 * @param {*} tenant
 * @param {*} venue
 * @param {*} accessTokenProviderCallbackAsync function called before connecting to STOMP server. Should return access token.
 * @param {*} onConnectedAsync async function (accessToken) {....}
 * @param {*} onDisconnectAsync
 * @param {*} onMessageAsync async function (message, accessToken) {....}
 */
export function connectWebSockets(params) {
    return __awaiter(this, void 0, void 0, function* () {
        let client;
        const baseURL = replaceProtocolInUrl(params.baseURL, 'wss://') + '/websocket';
        let userUUID = '';
        const stompConfig = {
            brokerURL: baseURL,
            debug: function (a) {
                //console.log('DEBUG: ' + a);
            },
            reconnectDelay: 20000,
            heartbeatIncoming: 4000,
            heartbeatOutgoing: 4000,
            beforeConnect: function () {
                return __awaiter(this, void 0, void 0, function* () {
                    //console.log('--- beforeConnect --- ');
                    const { token, UUID } = yield params.authDataProvider(baseURL, params.refreshTokenHandler, false);
                    if (!token) {
                        //console.error('Access token provider error - deactivating socket');
                        client.deactivate();
                        if (params.onAuthFailure)
                            params.onAuthFailure();
                    }
                    stompConfig.connectHeaders = { login: token /*passcode: ''*/ };
                    userUUID = UUID;
                });
            },
            onConnect: function () {
                return __awaiter(this, void 0, void 0, function* () {
                    if (!stompConfig.connectHeaders)
                        return;
                    const accessToken = stompConfig.connectHeaders.login;
                    yield params.onConnectedAsync(accessToken);
                    //console.log('Websocket connected.');
                    if (params.onKDSMessageAsync) {
                        var subscription = client.subscribe(`/kds/${params.tenant}/${params.venue}`, function (data) {
                            return __awaiter(this, void 0, void 0, function* () {
                                var message = JSON.parse(data.body);
                                yield params.onKDSMessageAsync(message);
                            });
                        });
                    }
                    if (params.onOrdersUpdateAsync) {
                        var subscriptionForOrdersUpdate = client.subscribe(`/order-changes/${params.tenant}/${userUUID}`, function (data) {
                            return __awaiter(this, void 0, void 0, function* () {
                                var message = JSON.parse(data.body);
                                yield params.onOrdersUpdateAsync(message);
                            });
                        });
                    }
                    if (params.onNotificationAsync) {
                        var subscriptionForNotifications = client.subscribe(`/notifications/${params.tenant}/${userUUID}`, function (data) {
                            return __awaiter(this, void 0, void 0, function* () {
                                var message = JSON.parse(data.body);
                                yield params.onNotificationAsync(message);
                            });
                        });
                    }
                });
            },
            onDisconnect: function () {
                return __awaiter(this, void 0, void 0, function* () {
                    yield params.onDisconnectAsync();
                    //console.log('Websocket disconnected.');
                });
            },
            onStompError: function (frame) {
                return __awaiter(this, void 0, void 0, function* () {
                    // Will be invoked in case of error encountered at Broker
                    // Bad login/passcode typically will cause an error
                    // Complaint brokers will set `message` header with a brief message. Body may contain details.
                    // Compliant brokers will terminate the connection after any error
                    //console.error('Broker reported error: ' + frame.headers['message']);
                    //console.error('Additional details: ' + frame.body);
                    yield client.deactivate();
                    client = createNewClient(stompConfig);
                    client.activate();
                });
            },
            onWebSocketClose: function () {
                //console.log('Websocket closed.');
            },
            onWebSocketError: function () {
                //console.log('Websocket error.');
            },
            onUnhandledMessage: function () { },
            logRawCommunication: true,
            discardWebsocketOnCommFailure: true,
        };
        try {
            const { token, UUID } = yield params.authDataProvider(params.baseURL, params.refreshTokenHandler, false);
            stompConfig.connectHeaders = { login: token /*passcode: ''*/ };
            client = createNewClient(stompConfig);
            client.activate();
        }
        catch (err) {
            console.error(err);
        }
    });
}
function createNewClient(stompConfig) {
    const _client = new StompJs.Client(stompConfig);
    if (typeof WebSocket !== 'function') {
        // Fallback code
        _client.webSocketFactory = () => {
            const WebSocket = require('ws');
            global.WebSocket = WebSocket;
            //console.log('create ws with ' + stompConfig.brokerURL);
            const ws = new WebSocket(stompConfig.brokerURL);
            return ws;
        };
    }
    return _client;
}
